@@ -22,27 +22,29 @@
 #include <libaudcore/audstrings.h>
 #include <libaudcore/i18n.h>
 #include <libaudcore/runtime.h>
+#include <libaudcore/vfs.h>
 
+#include "gtk-compat.h"
 #include "internal.h"
 #include "libaudgui.h"
 #include "libaudgui-gtk.h"
 
 static const char about_text[] = "<big><b>Audacious " VERSION "</b></big>\n" COPYRIGHT;
-static const char website[] = "http://audacious-media-player.org";
+static const char website[] = "https://audacious-media-player.org";
 
 static GtkWidget * create_credits_notebook (const char * credits, const char * license)
 {
-    const char * titles[2] = {_("Credits"), _("License")};
+    const char * titles[2] = {N_("Credits"), N_("License")};
     const char * text[2] = {credits, license};
 
     GtkWidget * notebook = gtk_notebook_new ();
 
     for (int i = 0; i < 2; i ++)
     {
-        GtkWidget * label = gtk_label_new (titles[i]);
+        GtkWidget * label = gtk_label_new (_(titles[i]));
 
         GtkWidget * scrolled = gtk_scrolled_window_new (nullptr, nullptr);
-        gtk_widget_set_size_request (scrolled, -1, 200);
+        gtk_widget_set_size_request (scrolled, -1, 2 * audgui_get_dpi ());
         gtk_scrolled_window_set_policy ((GtkScrolledWindow *) scrolled,
          GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
@@ -65,6 +67,8 @@ static GtkWidget * create_about_window ()
 {
     const char * data_dir = aud_get_path (AudPath::DataDir);
 
+    int dpi = audgui_get_dpi ();
+
     GtkWidget * about_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     gtk_window_set_title ((GtkWindow *) about_window, _("About Audacious"));
     gtk_window_set_resizable ((GtkWindow *) about_window, false);
@@ -72,11 +76,12 @@ static GtkWidget * create_about_window ()
 
     audgui_destroy_on_escape (about_window);
 
-    GtkWidget * vbox = gtk_vbox_new (false, 6);
+    GtkWidget * vbox = audgui_vbox_new (6);
     gtk_container_add ((GtkContainer *) about_window, vbox);
 
-    StringBuf logo_path = filename_build ({data_dir, "images", "about-logo.png"});
-    GtkWidget * image = gtk_image_new_from_file (logo_path);
+    AudguiPixbuf logo (gdk_pixbuf_new_from_resource_at_scale
+     ("/org/audacious/about-logo.svg", 4 * dpi, 2 * dpi, true, nullptr));
+    GtkWidget * image = gtk_image_new_from_pixbuf (logo.get ());
     gtk_box_pack_start ((GtkBox *) vbox, image, false, false, 0);
 
     GtkWidget * label = gtk_label_new (nullptr);
@@ -84,32 +89,24 @@ static GtkWidget * create_about_window ()
     gtk_label_set_justify ((GtkLabel *) label, GTK_JUSTIFY_CENTER);
     gtk_box_pack_start ((GtkBox *) vbox, label, false, false, 0);
 
-    GtkWidget * align = gtk_alignment_new (0.5, 0.5, 0, 0);
-    gtk_box_pack_start ((GtkBox *) vbox, align, false, false, 0);
-
     GtkWidget * button = gtk_link_button_new (website);
+
+#ifdef USE_GTK3
+    gtk_widget_set_halign (button, GTK_ALIGN_CENTER);
+    gtk_box_pack_start ((GtkBox *) vbox, button, false, false, 0);
+#else
+    GtkWidget * align = gtk_alignment_new (0.5, 0.5, 0, 0);
     gtk_container_add ((GtkContainer *) align, button);
+    gtk_box_pack_start ((GtkBox *) vbox, align, false, false, 0);
+#endif
 
-    char * credits, * license;
+    auto credits = VFSFile::read_file (filename_build ({data_dir, "AUTHORS"}), VFS_APPEND_NULL);
+    auto license = VFSFile::read_file (filename_build ({data_dir, "COPYING"}), VFS_APPEND_NULL);
 
-    StringBuf credits_path = filename_build ({data_dir, "AUTHORS"});
-    if (! g_file_get_contents (credits_path, & credits, nullptr, nullptr))
-        credits = g_strdup_printf ("Unable to load %s; check your installation.", (const char *) credits_path);
-
-    StringBuf license_path = filename_build ({data_dir, "COPYING"});
-    if (! g_file_get_contents (license_path, & license, nullptr, nullptr))
-        license = g_strdup_printf ("Unable to load %s; check your installation.", (const char *) license_path);
-
-    g_strchomp (credits);
-    g_strchomp (license);
-
-    GtkWidget * notebook = create_credits_notebook (credits, license);
-    gtk_widget_set_size_request (notebook, 585, 250);
+    GtkWidget * notebook = create_credits_notebook (credits.begin (), license.begin ());
+    gtk_widget_set_size_request (notebook, 6 * dpi, 2 * dpi);
     gtk_box_pack_start ((GtkBox *) vbox, notebook, true, true, 0);
 
-    g_free (credits);
-    g_free (license);
-
     return about_window;
 }
 
