@@ -25,6 +25,7 @@
 #include <libaudcore/i18n.h>
 #include <libaudcore/runtime.h>
 
+#include "gtk-compat.h"
 #include "internal.h"
 #include "libaudgui.h"
 #include "libaudgui-gtk.h"
@@ -68,13 +69,16 @@ static void slider_moved (GtkRange * slider)
 
 static GtkWidget * create_slider (const char * name, int band, GtkWidget * hbox)
 {
-    GtkWidget * vbox = gtk_vbox_new (false, 6);
+    GtkWidget * vbox = audgui_vbox_new (6);
 
     GtkWidget * label = gtk_label_new (name);
     gtk_label_set_angle ((GtkLabel *) label, 90);
     gtk_box_pack_start ((GtkBox *) vbox, label, true, false, 0);
 
-    GtkWidget * slider = gtk_vscale_new_with_range (-AUD_EQ_MAX_GAIN, AUD_EQ_MAX_GAIN, 1);
+    GtkAdjustment * adjustment = (GtkAdjustment *) gtk_adjustment_new (
+     0, -AUD_EQ_MAX_GAIN, AUD_EQ_MAX_GAIN, 1, 2, 0);
+    GtkWidget * slider = audgui_scale_new (GTK_ORIENTATION_VERTICAL, adjustment);
+    gtk_scale_set_digits ((GtkScale *) slider, 0);
     gtk_scale_set_draw_value ((GtkScale *) slider, true);
     gtk_scale_set_value_pos ((GtkScale *) slider, GTK_POS_BOTTOM);
     gtk_range_set_inverted ((GtkRange *) slider, true);
@@ -132,10 +136,10 @@ static GtkWidget * create_window ()
     gtk_container_set_border_width ((GtkContainer *) window, 6);
     audgui_destroy_on_escape (window);
 
-    GtkWidget * vbox = gtk_vbox_new (false, 6);
+    GtkWidget * vbox = audgui_vbox_new (6);
     gtk_container_add ((GtkContainer *) window, vbox);
 
-    GtkWidget * top_row = gtk_hbox_new (false, 6);
+    GtkWidget * top_row = audgui_hbox_new (6);
     gtk_box_pack_start ((GtkBox *) vbox, top_row, false, false, 0);
 
     gtk_box_pack_start ((GtkBox *) top_row, create_on_off (), false, false, 0);
@@ -148,13 +152,14 @@ static GtkWidget * create_window ()
      (AudguiCallback) reset_to_zero, nullptr);
     gtk_box_pack_end ((GtkBox *) top_row, zero, false, false, 0);
 
-    GtkWidget * hbox = gtk_hbox_new (false, 6);
+    GtkWidget * hbox = audgui_hbox_new (6);
     gtk_box_pack_start ((GtkBox *) vbox, hbox, false, false, 0);
 
     GtkWidget * preamp = create_slider (_("Preamp"), -1, hbox);
     g_object_set_data ((GObject *) window, "preamp", preamp);
 
-    gtk_box_pack_start ((GtkBox *) hbox, gtk_vseparator_new (), false, false, 0);
+    gtk_box_pack_start ((GtkBox *) hbox,
+     audgui_separator_new (GTK_ORIENTATION_VERTICAL), false, false, 0);
 
     for (int i = 0; i < AUD_EQ_NBANDS; i ++)
     {
