@@ -30,15 +30,13 @@
 #include <libaudcore/runtime.h>
 #include <libaudcore/tuple.h>
 
+#include "gtk-compat.h"
 #include "internal.h"
 #include "libaudgui.h"
 #include "libaudgui-gtk.h"
 
 static void infopopup_move_to_mouse (GtkWidget * infopopup);
 
-static const GdkColor gray = {0, 40960, 40960, 40960};
-static const GdkColor white = {0, 65535, 65535, 65535};
-
 static struct {
     GtkWidget * title_header, * title_label;
     GtkWidget * artist_header, * artist_label;
@@ -104,11 +102,17 @@ static void infopopup_progress_cb (void *)
 
 static void infopopup_realized (GtkWidget * widget)
 {
+#ifndef USE_GTK3
     GdkWindow * window = gtk_widget_get_window (widget);
     gdk_window_set_back_pixmap (window, nullptr, false);
+#endif
     infopopup_move_to_mouse (widget);
 }
 
+#ifndef USE_GTK3
+static const GdkColor gray = {0, 40960, 40960, 40960};
+static const GdkColor white = {0, 65535, 65535, 65535};
+
 static gboolean infopopup_draw_bg (GtkWidget * widget)
 {
     GtkAllocation alloc;
@@ -126,6 +130,7 @@ static gboolean infopopup_draw_bg (GtkWidget * widget)
     cairo_destroy (cr);
     return false;
 }
+#endif
 
 static void infopopup_add_category (GtkWidget * grid, int position,
  const char * text, GtkWidget * * header, GtkWidget * * label)
@@ -133,19 +138,27 @@ static void infopopup_add_category (GtkWidget * grid, int position,
     * header = gtk_label_new (nullptr);
     * label = gtk_label_new (nullptr);
 
+    CharPtr markup (g_markup_printf_escaped ("<span style=\"italic\">%s</span>", text));
+    gtk_label_set_markup ((GtkLabel *) * header, markup);
+
+#ifdef USE_GTK3
+    gtk_widget_set_halign (* header, GTK_ALIGN_END);
+    gtk_widget_set_halign (* label, GTK_ALIGN_START);
+
+    gtk_grid_attach ((GtkGrid *) grid, * header, 0, position, 1, 1);
+    gtk_grid_attach ((GtkGrid *) grid, * label, 1, position, 1, 1);
+#else
     gtk_misc_set_alignment ((GtkMisc *) * header, 1, 0.5);
     gtk_misc_set_alignment ((GtkMisc *) * label, 0, 0.5);
 
     gtk_widget_modify_fg (* header, GTK_STATE_NORMAL, & gray);
     gtk_widget_modify_fg (* label, GTK_STATE_NORMAL, & white);
 
-    CharPtr markup (g_markup_printf_escaped ("<span style=\"italic\">%s</span>", text));
-    gtk_label_set_markup ((GtkLabel *) * header, markup);
-
     gtk_table_attach ((GtkTable *) grid, * header, 0, 1, position, position + 1,
      GTK_FILL, GTK_FILL, 0, 0);
     gtk_table_attach ((GtkTable *) grid, * label, 1, 2, position, position + 1,
      GTK_FILL, GTK_FILL, 0, 0);
+#endif
 
     gtk_widget_set_no_show_all (* header, true);
     gtk_widget_set_no_show_all (* label, true);
@@ -172,7 +185,7 @@ static GtkWidget * infopopup_create ()
     gtk_window_set_decorated ((GtkWindow *) infopopup, false);
     gtk_container_set_border_width ((GtkContainer *) infopopup, 4);
 
-    GtkWidget * hbox = gtk_hbox_new (false, 6);
+    GtkWidget * hbox = audgui_hbox_new (6);
     gtk_container_add ((GtkContainer *) infopopup, hbox);
 
     widgets.image = gtk_image_new ();
@@ -180,8 +193,8 @@ static GtkWidget * infopopup_create ()
     gtk_box_pack_start ((GtkBox *) hbox, widgets.image, false, false, 0);
     gtk_widget_set_no_show_all (widgets.image, true);
 
-    GtkWidget * grid = gtk_table_new (0, 0, false);
-    gtk_table_set_col_spacings ((GtkTable *) grid, 6);
+    GtkWidget * grid = audgui_grid_new ();
+    audgui_grid_set_column_spacing (grid, 6);
     gtk_box_pack_start ((GtkBox *) hbox, grid, true, true, 0);
 
     infopopup_add_category (grid, 0, _("Title"), & widgets.title_header, & widgets.title_label);
@@ -195,18 +208,24 @@ static GtkWidget * infopopup_create ()
     /* track progress */
     widgets.progress = gtk_progress_bar_new ();
     gtk_progress_bar_set_text ((GtkProgressBar *) widgets.progress, "");
+
+#ifdef USE_GTK3
+    gtk_widget_set_margin_top (widgets.progress, 6);
+    gtk_progress_bar_set_show_text ((GtkProgressBar *) widgets.progress, true);
+    gtk_grid_attach ((GtkGrid *) grid, widgets.progress, 0, 7, 2, 1);
+#else
     gtk_table_set_row_spacing ((GtkTable *) grid, 6, 4);
     gtk_table_attach ((GtkTable *) grid, widgets.progress, 0, 2, 7, 8,
      GTK_FILL, GTK_FILL, 0, 0);
 
-    /* do not show the track progress */
-    gtk_widget_set_no_show_all (widgets.progress, true);
-
     /* override background drawing */
     gtk_widget_set_app_paintable (infopopup, true);
-
+    g_signal_connect (infopopup, AUDGUI_DRAW_SIGNAL, (GCallback) infopopup_draw_bg, nullptr);
+#endif
     g_signal_connect (infopopup, "realize", (GCallback) infopopup_realized, nullptr);
-    g_signal_connect (infopopup, "expose-event", (GCallback) infopopup_draw_bg, nullptr);
+
+    /* do not show the track progress */
+    gtk_widget_set_no_show_all (widgets.progress, true);
 
     return infopopup;
 }
